@@ -7,12 +7,12 @@ describe 'murano::db' do
         :db_max_retries          => '<SERVICE DEFAULT>',
         :connection              => 'mysql+pymysql://murano:secrete@localhost:3306/murano',
         :connection_recycle_time => '<SERVICE DEFAULT>',
-        :min_pool_size           => '<SERVICE DEFAULT>',
         :max_pool_size           => '<SERVICE DEFAULT>',
         :max_retries             => '<SERVICE DEFAULT>',
         :retry_interval          => '<SERVICE DEFAULT>',
         :max_overflow            => '<SERVICE DEFAULT>',
         :pool_timeout            => '<SERVICE DEFAULT>',
+        :mysql_enable_ndb        => '<SERVICE DEFAULT>',
       )}
     end
 
@@ -21,12 +21,12 @@ describe 'murano::db' do
         {
           :database_connection              => 'mysql+pymysql://murano:murano@localhost/murano',
           :database_connection_recycle_time => '3601',
-          :database_min_pool_size           => '2',
           :database_max_retries             => '11',
           :database_retry_interval          => '11',
           :database_max_pool_size           => '11',
           :database_max_overflow            => '21',
           :database_pool_timeout            => '21',
+          :mysql_enable_ndb                 => true,
           :database_db_max_retries          => '-1',
         }
       end
@@ -35,12 +35,12 @@ describe 'murano::db' do
         :db_max_retries          => '-1',
         :connection              => 'mysql+pymysql://murano:murano@localhost/murano',
         :connection_recycle_time => '3601',
-        :min_pool_size           => '2',
         :max_pool_size           => '11',
         :max_retries             => '11',
         :retry_interval          => '11',
         :max_overflow            => '21',
         :pool_timeout            => '21',
+        :mysql_enable_ndb        => true,
       )}
     end
   end
