@@ -10,7 +10,14 @@ describe 'murano::db::sync' do
         :path        => '/usr/bin',
         :user        => 'murano',
         :refreshonly => 'true',
-        :logoutput   => 'on_failure'
+        :try_sleep   => 5,
+        :tries       => 10,
+        :logoutput   => 'on_failure',
+        :subscribe   => ['Anchor[murano::install::end]',
+                         'Anchor[murano::config::end]',
+                         'Anchor[murano::dbsync::begin]'],
+        :notify      => 'Anchor[murano::dbsync::end]',
+        :tag         => 'openstack-db',
       )
     end
 
@@ -22,7 +29,6 @@ describe 'murano::db::sync' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
           :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
